@@ -1,9 +1,6 @@
 /** @format */
 
-define(["dojo/_base/declare", "dijit/form/Button"], function (
-    declare,
-    button
-) {
+define(["dojo/_base/declare", "dijit/form/Button"], function (declare, button) {
     return declare("lsmb/payments/JumpScreenButton", [button], {
         url: null,
         onClick: function () {
