@@ -24,17 +24,15 @@ define([
             this.initialValue = arguments[0].value;
         },
         startup: function () {
-            var self = this;
             this.inherited(arguments);
             if (this.channel) {
                 this.own(
-                    topic.subscribe(this.channel, function (selected) {
-                        self.set("value", selected[self.searchAttr]);
+                    topic.subscribe(this.channel, (selected) => {
+                        this.set("value", selected[this.searchAttr]);
                     })
                 );
-                // eslint-disable-next-line no-unused-vars
-                this.on("change", function (newValue) {
-                    topic.publish(self.channel, self.item);
+                this.on("change", () => {
+                    topic.publish(this.channel, this.item);
                 });
             }
         }
