@@ -24,6 +24,22 @@ export class LsmbDate extends LsmbBaseInput {
     _widgetClass() {
         return dojoDateBox;
     }
+
+    _collectProps() {
+        let props = super._collectProps();
+        if (props.value === "today") {
+            props.value = new Date();
+        }
+        return props;
+    }
+
+    disconnectedCallback() {
+        if (this.widgetWrapper) {
+            this.widgetWrapper.remove();
+            this.widgetWrapper = null;
+        }
+        super.disconnectedCallback();
+    }
 }
 
 customElements.define("lsmb-date", LsmbDate);
