@@ -4,7 +4,7 @@ const rtlDetect = require("rtl-detect");
 
 import { createI18n } from "vue-i18n";
 
-const SUPPORT_LOCALES = [ "en", "fr_CA", "ar_EG" ];
+const SUPPORT_LOCALES = ["en", "fr_CA", "ar_EG"];
 
 function _mapLocale(locale) {
     const _locale = locale.match(/([a-z]{2})-([a-z]{2})/);
@@ -17,7 +17,7 @@ function _mapLocale(locale) {
 var _messages = {};
 SUPPORT_LOCALES.forEach(function (it) {
     const locale = _mapLocale(it);
-    // eslint-disable-next-line global-require
+    // eslint-disable-next-line import-x/no-dynamic-require, global-require
     _messages[locale] = require("@/locales/" + locale + ".json");
 });
 
@@ -35,8 +35,10 @@ export async function setI18nLanguage(lang) {
     const locale = _mapLocale(lang.value);
 
     // If the language hasn't been loaded yet
-    if (i18n.global.availableLocales.includes(locale) &&
-        await document.querySelector("html").setAttribute("lang", locale)) {
+    if (
+        i18n.global.availableLocales.includes(locale) &&
+        document.querySelector("html").setAttribute("lang", locale)
+    ) {
         if (rtlDetect.isRtlLang(locale)) {
             document.querySelector("html").setAttribute("dir", "rtl");
         }
