@@ -1,3 +1,8 @@
+
+use v5.36;
+use warnings;
+use experimental 'try';
+
 package LedgerSMB::Admin::Command::user;
 
 =head1 NAME
@@ -6,9 +11,6 @@ LedgerSMB::Admin::Command::user - ledgersmb-admin 'user' command
 
 =cut
 
-use strict;
-use warnings;
-
 use Getopt::Long qw(GetOptionsFromArray);
 use LedgerSMB::Admin::Command;
 use LedgerSMB::App_State;
@@ -22,11 +24,10 @@ use LedgerSMB::User;
 use Array::PrintCols;
 
 use Moose;
+use experimental 'try'; # Work around Moose re-enabling experimenal warnings
 extends 'LedgerSMB::Admin::Command';
 use namespace::autoclean;
 
-use Feature::Compat::Try;
-
 has options => (is => 'ro', default => sub { {} });
 
 sub _get_valid_salutation {
