@@ -1,10 +1,10 @@
 
-package LedgerSMB::Database::PostUpgrade::CogsAllocationCleanup;
-
-use strict;
+use v5.36;
 use warnings;
 use experimental qw( signatures );
 
+package LedgerSMB::Database::PostUpgrade::CogsAllocationCleanup;
+
 =head1 NAME
 
 LedgerSMB::Database::PostUpgrade::CogsAllocationCleanup - Cleanup of backup tables created on upgrade
@@ -15,7 +15,9 @@ LedgerSMB::Database::PostUpgrade::CogsAllocationCleanup - Cleanup of backup tabl
 
 =head1 DESCRIPTION
 
-
+This post-upgrade action removes the C<invoice_before_cogs_allocation_fix> table which
+is created as part of the upgrade script in C<sql/changes/1.11/cogs-allocation.sql>. The
+upgrade script schedules this action to be run 5 years in the future.
 
 =head1 METHODS
 
