@@ -43,8 +43,6 @@ use LedgerSMB::Form;
 use LedgerSMB::Legacy_Util;
 use LedgerSMB::PGObject;
 use LedgerSMB::Scripts::login;
-use LedgerSMB::Setting;
-use LedgerSMB::Setting::Sequence;
 use LedgerSMB::Tax;
 
 
