@@ -31,7 +31,7 @@ use HTTP::Status qw( HTTP_OK HTTP_UNAUTHORIZED HTTP_INTERNAL_SERVER_ERROR
 use parent 'Exporter';
 our @EXPORT_OK = qw(
     internal_server_error unauthorized session_timed_out
-    incompatible_database cookie_path template_response
+    incompatible_database template_response
     );
 
 =head1 METHODS
@@ -90,7 +90,7 @@ Returns a standard error representation for 'LedgerSMB session timed out'
 
 sub session_timed_out {
     return [ HTTP_SEE_OTHER,
-             [ 'Location' => 'login.pl?__action=logout&reason=timeout' ],
+             [ 'Location' => 'logout.pl?__action=logout&reason=timeout' ],
              [] ];
 }
 
@@ -115,20 +115,6 @@ sub incompatible_database {
 }
 
 
-=head2 cookie_path($script)
-
-Returns the C<path=> parameter to be used with the C<Set-Cookie>
-(authorization) header.
-
-=cut
-
-sub cookie_path {
-    my $script = shift;
-
-    return ($script =~ s|[^/]*$||r);
-}
-
-
 =head2 template_response( $template, %args )
 
 Transform a template into a PSGI response, taking additional args
