@@ -47,7 +47,6 @@ use LedgerSMB::Entity::Credit_Account;
 use LedgerSMB::Magic qw( EC_CUSTOMER EC_VENDOR OEC_SALES_ORDER OEC_PURCHASE_ORDER );
 use LedgerSMB::PGNumber;
 use LedgerSMB::Part;
-use LedgerSMB::Setting;
 
 use LedgerSMB::Router appname => 'erp/api';
 
@@ -272,7 +271,8 @@ sub _get_orders_by_id {
 
     $ord{workflow} = {
         state => $wf->state,
-        actions => [ sort $wf->get_current_actions ]
+        actions => [ grep { ($wf->get_action( $_ )->ui // '') ne 'none' }
+                     sort $wf->get_current_actions ]
     };
 
     return [ HTTP_OK,
