@@ -122,8 +122,10 @@ Displays a list of all asset classes.  No inputs required.
 sub asset_category_results {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Listings::Asset_Class->new(%$request)
-        );
+        LedgerSMB::Report::Listings::Asset_Class->new(
+            %$request,
+            formatter_options => $request->formatter_options
+        ));
 }
 
 =item edit_asset_class
@@ -180,7 +182,7 @@ sub _asset_get_next_tag {
 sub _asset_get {
     my ($request) = @_;
 
-    my ($ref) = $request->call_procedure( funcname => 'asset__get', args => [ $request->{id} ]);
+    my ($ref) = $request->call_procedure( funcname => 'asset__get', args => [ $request->{id}, $request->{tag} ]);
     return $ref;
 }
 
@@ -244,8 +246,16 @@ Searches for asset items and displays them
 sub asset_results {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Listings::Asset->new(%$request)
-        );
+        LedgerSMB::Report::Listings::Asset->new(
+            $request->%{ qw( asset_class description
+                             tag usable_life) },
+            _locale => $request->{_locale},
+            _uri => $request->{_uri},
+            formatter_options => $request->formatter_options,
+            purchase_date => $request->parse_date( $request->{purchase_date} ),
+            purchase_value => $request->parse_amount( $request->{purchase_value} ),
+            salvage_value => $request->parse_amount( $request->{salvage_value} ),
+        ));
 }
 
 =item asset_save
@@ -331,6 +341,7 @@ sub _asset_report_get_metadata {
     my ($request) = @_;
 
     return {
+        depreciation  => $request->{depreciation},
         asset_classes => [ $request->call_procedure( funcname => 'asset_class__list', args => [] ) ],
         disp_methods  => [ $request->call_procedure( funcname => 'asset_report__get_disposal_methods', args => [] ) ],
         cash_accounts => [
@@ -416,7 +427,8 @@ sub report_save{
         my ($ref) = $request->call_procedure(
             funcname => 'asset_report__save',
             args     => [
-                $request->@{qw( id report_date report_class asset_class )}
+                $request->@{qw( id report_date report_class asset_class )},
+                1
             ]);
 
         my $id = $ref->{id};
@@ -692,7 +704,7 @@ sub report_results {
             report_date    => $r->{report_date},
             entered_at     => $r->{entered_at},
             approved_at    => $r->{approved_at},
-            total          => $r->{total}->to_output(money => 1),
+            total          => $request->format_amount($r->{total}, money => 1),
         };
         for my $ac (@{$ar->{asset_classes}}){
             if ($ac->{id} == $r->{asset_class}){
@@ -809,12 +821,12 @@ sub report_details {
 
     my $title =
         $locale->text('Report [_1] on date [_2]',
-                      $report->{id}, $report->{report_date}->to_output);
+                      $report->{id}, $request->format_amount( $report->{report_date} ) );
     my $rows = [];
     for my $r (@{$report->{report_lines}}){
         for my $amt (qw(purchase_value basis prior_dep dep_this_time dep_ytd
                         dep_total)){
-             $r->{$amt} = $r->{$amt}->to_output(money  => 1);
+             $r->{$amt} = $request->format_amount( $r->{$amt}, money  => 1);
         }
         push @$rows, $r;
     }
@@ -911,7 +923,7 @@ sub partial_disposal_details {
         for my $amt (qw(purchase_value disposed_acquired_value
                      remaining_aquired_value percent_disposed
                      percent_remaining)){
-             $r->{$amt} = $r->{$amt}->to_output(money => 1);
+             $r->{$amt} = $request->format_amount( $r->{$amt}, money => 1);
         }
 #        $r->{gain_loss} = $r->{gain_loss}->to_output(
 #                                                    money => 1,
@@ -1021,7 +1033,7 @@ sub disposal_details {
         for my $amt (qw(purchase_value adj_basis accum_depreciation
                         disposal_amt gain_loss)
         ){
-             $r->{$amt} = $r->{$amt}->to_output(money  => 1);
+             $r->{$amt} = $request->format_amount( $r->{$amt}, money  => 1);
         }
         push @$rows, $r;
     }
@@ -1126,8 +1138,10 @@ No inputs required or used.
 sub display_nbv {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Assets::Net_Book_Value->new(%$request)
-        );
+        LedgerSMB::Report::Assets::Net_Book_Value->new(
+            %$request,
+            formatter_options => $request->formatter_options
+        ));
 }
 
 =item begin_import
@@ -1214,10 +1228,10 @@ sub run_import {
           $ai->{$file_columns[$_]} = $ail->[$_];
         }
         next if $ai->{purchase_value} !~ /\d/;
-        $ai->{purchase_value} = LedgerSMB::PGNumber->from_input(
+        $ai->{purchase_value} = $request->parse_amount(
              $ai->{purchase_value}
         );
-        $ai->{accum_dep} = LedgerSMB::PGNumber->from_input($ai->{accum_dep});
+        $ai->{accum_dep} = $request->parse_amount($ai->{accum_dep});
         $ai->{dep_account} = $default_dep_account if !$ai->{dep_account};
         $ai->{asset_account} = $default_asset_account if !$ai->{dep_account};
         if (!$ai->{start_depreciation}){
