@@ -129,8 +129,10 @@ If set, excludes those which are not associated with customers/vendors.
 sub list {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Listings::Business_Unit->new(%$request)
-        );
+        LedgerSMB::Report::Listings::Business_Unit->new(
+            %$request,
+            formatter_options => $request->formatter_options
+        ));
 }
 
 =item delete
@@ -202,10 +204,10 @@ sub _save {
               if LedgerSMB::Setting::Sequence->should_increment(
                         $request, 'control_code', $request->{sequence});
     }
-    $request->{start_date} = LedgerSMB::PGDate->from_input($request->{start_date}, 0)
-                              if defined $request->{start_date};
-    $request->{end_date} = LedgerSMB::PGDate->from_input($request->{end_date}, 0)
-                              if defined $request->{end_date};
+    $request->{start_date} = $request->parse_date( $request->{start_date} )
+        if defined $request->{start_date};
+    $request->{end_date} = $request->parse_date( $request->{end_date})
+        if defined $request->{end_date};
     my $unit = LedgerSMB::Business_Unit->new(%$request);
     $unit = $unit->save;
 
