@@ -1,4 +1,8 @@
 
+use v5.36;
+use warnings;
+use experimental 'try';
+
 package LedgerSMB::Scripts::contact;
 
 =head1 NAME
@@ -14,11 +18,8 @@ This module is the UI controller for the customer, vendor, etc functions; it
 
 =cut
 
-use v5.36;
-use warnings;
-use Scalar::Util qw( blessed );
-
-use Feature::Compat::Try;
+use File::Spec;
+use HTTP::Status qw( HTTP_FOUND );
 
 use LedgerSMB;
 use LedgerSMB::Entity::Company;
@@ -36,7 +37,6 @@ use LedgerSMB::File;
 use LedgerSMB::I18N;
 use LedgerSMB::Magic qw( EC_EMPLOYEE );
 use LedgerSMB::Part;
-use LedgerSMB::Setting;
 
 use LedgerSMB::old_code qw(dispatch);
 
@@ -64,6 +64,23 @@ for (@pluginmods){
 
 =over
 
+=item delete_entity
+
+=cut
+
+sub delete_entity {
+    my ($request) = @_;
+    my $entity =
+           LedgerSMB::Entity::Company->get_by_cc($request->{control_code});
+    $entity ||=  LedgerSMB::Entity::Person->get_by_cc($request->{control_code});
+
+    $entity->del;
+    return [ HTTP_FOUND,
+             [ 'Location' => 'reports.pl?__action=start_report&report_name=contact_search' ],
+             [ '' ]
+        ];
+}
+
 =item get_by_cc
 
 Populates the company area with info on the company, pulled up through the
@@ -84,9 +101,9 @@ sub get_by_cc {
     $entity ||=  LedgerSMB::Entity::Person->get_by_cc($request->{control_code});
     my ($company, $person) = (undef, undef);
 
-    if (blessed $entity and $entity->isa('LedgerSMB::Entity::Company')) {
+    if ($entity isa 'LedgerSMB::Entity::Company'){
         $company = $entity;
-    } elsif (blessed $entity and $entity->isa('LedgerSMB::Entity::Person')) {
+    } elsif ($entity isa 'LedgerSMB::Entity::Person'){
         $person = $entity;
     }
 
@@ -116,9 +133,10 @@ sub get {
     $entity ||= LedgerSMB::Entity::Person->get($request->{entity_id});
     my ($company, $person) = (undef, undef);
 
-    if (blessed $entity and $entity->isa( 'LedgerSMB::Entity::Company')) {
+    local $@ = undef;
+    if ($entity isa 'LedgerSMB::Entity::Company') {
         $company = $entity;
-    } elsif (blessed $entity and $entity->isa('LedgerSMB::Entity::Person')) {
+    } elsif ($entity isa 'LedgerSMB::Entity::Person') {
         $person = $entity;
     }
 
@@ -169,6 +187,7 @@ sub _main_screen {
     $request->{target_div} ||= 'person_div' if defined $person;
     $request->{target_div} ||= 'company_div';
 
+    my $may_delete = $request->is_allowed_role({ allowed_roles => [ 'contact_delete' ] });
     my @all_managers =
         map { $_->{label} = "$_->{first_name} $_->{last_name}"; $_ }
     ($request->call_procedure( funcname => 'employee__all_managers' ),);
@@ -286,7 +305,7 @@ sub _main_screen {
 
     my @all_currencies =
         map { { curr => $_ } }
-        (LedgerSMB::Setting->new(%$request))->get_currencies;
+        $request->setting->get_currencies;
 
     my $default_country = $request->setting->get('default_country');
     my ($default_language) = $request->setting->get('default_language');
@@ -303,9 +322,10 @@ sub _main_screen {
     $request->close_form() if eval {$request->can('close_form')};
     $request->open_form() if eval {$request->can('close_form')};
 
-    my $ui_root = $request->{_wire}->get('ui')->{root} // './UI/';
-    opendir(my $dh2, "${ui_root}Contact/plugins") || die "can't opendir plugins directory: $!";
-    my @plugins = grep { /^[^.]/ && -f "${ui_root}Contact/plugins/$_" } readdir($dh2);
+    my $ui_root = $request->{_wire}->get('ui')->{root} // './UI';
+    my $plugins_dir = File::Spec->catdir($ui_root, 'Contact/plugins');
+    opendir(my $dh2, $plugins_dir) || die "can't opendir plugins directory: $!";
+    my @plugins = grep { /^[^.]/ && -f File::Spec->catfile($plugins_dir, $_) } readdir($dh2);
     closedir $dh2;
 
     my @country_list = $request->enabled_countries->@*;
@@ -367,7 +387,8 @@ sub _main_screen {
              all_managers => \@all_managers,
           default_country => $default_country,
          default_language => $default_language,
-                  earn_id => $earn_id
+                  earn_id => $earn_id,
+               may_delete => $may_delete,
     });
 }
 
@@ -602,6 +623,23 @@ sub save_person {
     return _main_screen($request, undef, $person);
 }
 
+=item delete_credit($request)
+
+Deletes the credit account indicated by C<< $request->{credit_id} >>, if the user
+has sufficient access rights.
+
+=cut
+
+sub delete_credit {
+    my ($request) = @_;
+
+    my $credit = LedgerSMB::Entity::Credit_Account->get_by_id( $request->{credit_id} );
+    if ($credit) {
+        $credit->del;
+    }
+    return get($request);
+}
+
 =item save_credit($request)
 
 This inserts or updates a credit account of the sort listed here.
