@@ -766,7 +766,7 @@ sub payment {
             name  => 'account_class',
             value => $dbPayment->{account_class}
         },
-        type => {
+        paymenttype => {
             name  => 'type',
             value => $request->{type}
         },
@@ -1198,11 +1198,16 @@ sub payment2 {
             value => $request->{curr}, },
         column_headers => \@column_headers,
         rows        =>  \@invoice_data,
-        topay_subtotal => $request->format_amount(
+        topayfx_subtotal => $request->format_amount(
             LedgerSMB::PGNumber->new(
                 (sum map {$request->parse_amount($_->{topay_fx}->{value} // 0)} @invoice_data) // 0
             ),
             money => 1),
+        topay_subtotal => $request->format_amount(
+            LedgerSMB::PGNumber->new(
+                (sum map {$request->parse_amount($_->{topay_fx}->{value} // 0)} @invoice_data) // 0
+            ) / ($request->{exrate} // 1),
+            money => 1),
         topay_state   => \@topay_state,
         vendorcustomer => {
             name => 'vendor-customer',
@@ -1225,10 +1230,23 @@ sub payment2 {
         notes => $request->{notes},
         overpayment         => \@overpayment,
         overpayment_account => \@overpayment_account,
+        overpaymentfx_subtotal => $request->format_amount(
+            LedgerSMB::PGNumber->new(
+                (sum map {$request->parse_amount($_->{amount} // 0)} @overpayment)
+                + $request->parse_amount(0) # never end up with undef
+            ),
+            money => 1),
         overpayment_subtotal => $request->format_amount(
             LedgerSMB::PGNumber->new(
                 (sum map {$request->parse_amount($_->{amount} // 0)} @overpayment)
                 + $request->parse_amount(0) # never end up with undef
+            ) / ($request->{exrate} // 1),
+            money => 1),
+        paymentfx_total => $request->format_amount(
+            LedgerSMB::PGNumber->new(
+                (sum map {$request->parse_amount($_->{amount} // 0)} @overpayment)
+                + (sum map {$request->parse_amount($_->{topay_fx}->{value}  // 0)} @invoice_data)
+                + $request->parse_amount(0) # never end up with undef
             ),
             money => 1),
         payment_total => $request->format_amount(
@@ -1236,7 +1254,7 @@ sub payment2 {
                 (sum map {$request->parse_amount($_->{amount} // 0)} @overpayment)
                 + (sum map {$request->parse_amount($_->{topay_fx}->{value}  // 0)} @invoice_data)
                 + $request->parse_amount(0) # never end up with undef
-            ),
+            ) / ($request->{exrate} // 1),
             money => 1),
     };
 
