@@ -18,6 +18,8 @@ use strict;
 use warnings;
 
 use HTTP::Status qw( HTTP_BAD_REQUEST );
+use Log::Any qw($log);
+use Workflow::Context;
 
 use LedgerSMB::DBObject::Reconciliation;
 use LedgerSMB::File;
@@ -61,7 +63,7 @@ and re-renders the reconciliation screen.
 sub update_recon_set {
     my ($request) = shift;
     my $recon = LedgerSMB::DBObject::Reconciliation->new(%$request);
-    $recon->{their_total} = LedgerSMB::PGNumber->from_input(
+    $recon->{their_total} = $request->parse_amount(
         $recon->{their_total}
     ) if defined $recon->{their_total};
     $recon->save() if !$recon->{submitted};
@@ -102,13 +104,9 @@ must be set:
 sub reject {
     my ($request) = @_;
 
-    my $recon_data = {
-        dbh => $request->{dbh},
-        report_id => $request->{report_id}
-    };
-
-    my $recon = LedgerSMB::DBObject::Reconciliation->new(%$recon_data);
-    $recon->reject;
+    my $wf = $request->{_wire}->get('workflows')
+        ->fetch_workflow( 'reconciliation', $request->{workflow_id} );
+    $wf->execute_action( 'reject' );
 
     return search($request);
 }
@@ -121,8 +119,11 @@ Submits the recon set to be approved.
 
 sub submit_recon_set {
     my ($request) = shift;
+    my $wf = $request->{_wire}->get('workflows')
+        ->fetch_workflow( 'reconciliation', $request->{workflow_id} );
+    $wf->execute_action( 'submit' );
+
     my $recon = LedgerSMB::DBObject::Reconciliation->new(%$request);
-    $recon->submit();
     my $can_approve = $request->is_allowed_role(
         {allowed_roles => ['reconciliation_approve']}
     );
@@ -163,8 +164,16 @@ Displays the search results
 sub get_results {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Reconciliation::Summary->new(%$request)
-        );
+        LedgerSMB::Report::Reconciliation::Summary->new(
+            $request->%{ qw( account_id approved submitted language _locale
+                             interval from_month from_year comparison_periods
+                             comparison_type comparisons ) },
+            formatter_options => $request->formatter_options,
+            balance_from => $request->parse_amount( $request->{balance_from} ),
+            balance_to => $request->parse_amount( $request->{balance_to} ),
+            from_date => $request->parse_date( $request->{from_date} ),
+            to_date => $request->parse_date( $request->{to_date} ),
+        ));
 }
 
 =item search($request)
@@ -192,6 +201,7 @@ sub search {
     $recon->set_dbh($request->{dbh});
     $recon->get_accounts();
 
+    $log->info('render');
     my $template = $request->{_wire}->get('ui');
     return $template->render(
         $request,
@@ -253,7 +263,7 @@ sub _display_report {
     /) {
         for my $bal_type (qw/ credits debits/) {
             $recon->{"$amt_name$bal_type"} = (
-                $recon->{"$amt_name$bal_type"}->to_output(money => 1)
+                $request->format_amount( $recon->{"$amt_name$bal_type"}, money => 1)
             );
         }
     }
@@ -267,7 +277,7 @@ sub _display_report {
             their_credits
             their_debits
         /) {
-            $line->{$element} = $line->{$element}->to_output(money => 1);
+            $line->{$element} = $request->format_amount( $line->{$element}, money => 1);
         }
     }
 
@@ -280,7 +290,7 @@ sub _display_report {
         our_total
         beginning_balance
     /) {
-        $recon->{$field} = $recon->{$field}->to_output(money => 1);
+        $recon->{$field} = $request->format_amount( $recon->{$field}, money => 1);
     }
 
     my $template = $request->{_wire}->get('ui');
@@ -345,20 +355,24 @@ sub start_report {
     }
 
     my $recon_data = {
-        dbh => $request->{dbh},
-        chart_id => $request->{chart_id},
-        end_date => $request->{end_date},
-        total => $request->{total},
-        recon_fx => $request->{recon_fx},
+        account_id     => $request->{chart_id},
+        end_date       => $request->{end_date},
+        ending_balance => $request->{total},
+        recon_fx       => $request->{recon_fx},
     };
+    my $ctx = Workflow::Context->new(%$recon_data);
+    my $wf = $request->{_wire}->get( 'workflows' )->
+        create_workflow( 'reconciliation', $ctx );
 
-    my $recon = LedgerSMB::DBObject::Reconciliation->new(%$recon_data);
-
-    # Insert new report into database
-    $recon->new_report;
+    my $recon = LedgerSMB::DBObject::Reconciliation->new(
+        dbh => $request->{dbh},
+        report_id => $wf->context->param( 'id' ),
+        workflow_id => $wf->id,
+        );
+    $recon->refresh_pending_transactions;
 
     # Format ending balance as a PGNumber - required for display
-    $recon->{their_total} = LedgerSMB::PGNumber->from_input($request->{total});
+    $recon->{their_total} = $request->parse_amount($request->{total});
     delete $recon->{total};
 
     return _display_report($recon, $request);
@@ -378,11 +392,10 @@ delete any non-approved reports.
 sub delete_report {
     my ($request) = @_;
 
-    my $recon = LedgerSMB::DBObject::Reconciliation->new(%$request);
+    my $wf = $request->{_wire}->get('workflows')
+        ->fetch_workflow( 'reconciliation', $request->{workflow_id} );
+    $wf->execute_action( 'delete' );
 
-    $recon->delete($request->{report_id});
-
-    delete($request->{report_id});
     return search($request);
 }
 
@@ -409,11 +422,12 @@ sub approve {
              [ q{'report_id' parameter missing} ]
         ] if ! $request->{report_id};
 
-    my $recon = LedgerSMB::DBObject::Reconciliation->new(%$request);
+    my $wf = $request->{_wire}->get('workflows')
+        ->fetch_workflow( 'reconciliation', $request->{workflow_id} );
+    $wf->execute_action( 'approve' );
 
-    my $code = $recon->approve;
-    my $template = $code == 0 ? 'reconciliation/approved'
-        : 'reconciliation/report';
+    my $recon = LedgerSMB::DBObject::Reconciliation->new(%$request);
+    my $template = 'reconciliation/approved';
     return $request->{_wire}->get('ui')
         ->render($request, $template, $recon);
 }
