@@ -58,6 +58,8 @@ sub run_report{
     return $request->render_report(
         LedgerSMB::Report::Aging->new(
             %$request,
+            to_date   => $request->parse_date( $request->{to_date} ),
+            formatter_options => $request->formatter_options,
             language => $request->{_user}->{language},
             languages => $request->enabled_languages
         ));
@@ -322,12 +324,15 @@ sub generate_statement {
         );
         my $aging_report = LedgerSMB::Report::Aging->new(
             %$request,
+            to_date   => $request->parse_date( $request->{to_date} ),
             (ref $filters{$eca}) ? (details_filter => $filters{$eca}) : (),
             languages => $request->enabled_languages,
             entity_id => $entity_id,
-            credit_id => $credit_act->id
+            credit_id => $credit_act->id,
+            formatter_options => $request->formatter_options,
             );
         $aging_report->run_report($request);
+        $aging_report->format_money_columns;
         my $statement = {
               aging => $aging_report,
              entity => $company,
@@ -364,6 +369,7 @@ sub generate_statement {
         $sink = LedgerSMB::Template::Sink::Printer->new(
             wire    => $request->{_wire},
             command => $cmd,
+            printer => $request->{media}
             );
     }
 
@@ -379,6 +385,7 @@ sub generate_statement {
                 method          => $request->{media},
                 format_plugin   => ($request->{_wire}->get( 'output_formatter' )
                                     ->get( $request->{print_format})),
+                formatter_options => $request->formatter_options,
                 );
 
         $template->render(
@@ -423,7 +430,7 @@ sub generate_statement {
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2012-2022 The LedgerSMB Core Team
+Copyright (C) 2012-2024 The LedgerSMB Core Team
 
 This file is licensed under the GNU General Public License version 2, or at your
 option any later version.  A copy of the license should have been included with
