@@ -51,8 +51,12 @@ sub run {
     delete $request->{business_units}
     unless scalar @{$request->{business_units}};
     return $request->render_report(
-        LedgerSMB::Report::Trial_Balance->new(%$request)
-        );
+        LedgerSMB::Report::Trial_Balance->new(
+            %$request,
+            formatter_options => $request->formatter_options,
+            from_date => $request->parse_date( $request->{from_date} ),
+            to_date => $request->parse_date( $request->{to_date} ),
+        ));
 }
 
 =back
