@@ -29,9 +29,8 @@ use warnings;
 use feature 'fc';
 
 use DateTime::Format::Duration::ISO8601;
+use File::Spec;
 use Locale::CLDR;
-use Math::BigFloat;
-use Math::BigInt;
 
 use LedgerSMB::Locale;
 use LedgerSMB::User;
@@ -70,8 +69,9 @@ my $numberformats = [
 sub _css_options {
     my ($wire) = shift;
 
-    my $ui_root = $wire->get('ui')->{root} // './UI/';
-    opendir CSS,  "${ui_root}css";
+    my $ui_root = $wire->get('ui')->{root} // './UI';
+    opendir CSS, File::Spec->catdir($ui_root, 'css')
+        or die "can't open css directory: $!";
     my @cssfiles =
         map { +{ file => $_ } }
         grep { /.*\.css$/ }
@@ -134,11 +134,7 @@ sub preference_screen {
                 dateformats      => $dateformats,
                 language_codes   => _language_options(
                     $request,
-                    do {
-                        local $Math::BigInt::upgrade = undef;
-                        local $Math::BigFloat::downgrade = undef;
-                        Locale::CLDR->new( $prefs->{language} );
-                    }),
+                    Locale::CLDR->new( $prefs->{language} )),
                 login            => $login,
                 numberformats    => $numberformats,
                 password_expires => {
