@@ -1,3 +1,7 @@
+
+use v5.36;
+use warnings;
+
 package LedgerSMB::Workflow::Condition::SeparateDuties;
 
 =head1 NAME
@@ -23,14 +27,11 @@ separation of duties.
 =cut
 
 
-use strict;
-use warnings;
 use parent qw( Workflow::Condition );
 
 use LedgerSMB::Setting;
 
 use Log::Any qw($log);
-use Workflow::Exception qw( condition_error );
 
 
 =head2 evaluate( $wf )
@@ -40,17 +41,12 @@ error in case separation of duties is I<not> enabled.
 
 =cut
 
-sub evaluate {
-    my ($self, $wf) = @_;
-    my $dbh = $wf->_factory->
-        get_persister_for_workflow_type( $wf->type )->handle;
-
+sub evaluate($self, $wf) {
+    my $dbh = $wf->handle;
     my $separate_duties = LedgerSMB::Setting->new(dbh => $dbh)->get('separate_duties');
     $log->info("separate duties: $separate_duties");
-    condition_error 'Separation of Duties disabled'
-        if not $separate_duties;
 
-    return 1;
+    return $separate_duties;
 }
 
 
