@@ -131,7 +131,7 @@ sub display_taxes {
 
     my @rows;
     my $sametax = '';
-    $form->{_setting_decimal_places} //= LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} //= $form->get_setting('decimal_places');
     for ( split( / /, $form->{taxaccounts} ) ) {
 
         ( $null, $i ) = split /_/, $_;
@@ -330,7 +330,7 @@ sub recurring_transactions {
     my @transactions;
     my $j;
     my $k;
-    $form->{_setting_decimal_places} //= LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} //= $form->get_setting('decimal_places');
     foreach my $transaction ( sort keys %{ $form->{transactions} } ) {
         my $transaction_count = scalar( @{ $form->{transactions}{$transaction} } );
         push @transactions, {type => $transaction,
@@ -391,7 +391,7 @@ sub recurring_transactions {
 
             $column_data{id} = {
                 text => $ref->{id},
-                href => qq|$module?__action=edit&id=$ref->{id}&vc=$ref->{vc}&type=$type&readonly=1|,
+                href => qq|$module?__action=edit&id=$ref->{id}&vc=$ref->{vc}&type=$type|,
                 };
 
             $column_data{repeat} = $repeat;
@@ -524,7 +524,7 @@ sub process_transactions {
     $myconfig{vclimit} = 0;
     %f = &formnames;
 
-    $form->{_setting_decimal_places} //= LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} //= $form->get_setting('decimal_places');
     for ( my $i = 1 ; $i <= $pt->{lastndx} ; $i++ ) {
         if ( $pt->{"ndx_$i"} ) {
             $id = $pt->{"ndx_$i"};
@@ -642,7 +642,7 @@ sub process_transactions {
                         $form->{paidaccounts} = -1;
                     }
 
-                    for (qw(id workflow_id recurring intnotes printed emailed)) {
+                    for (qw(id workflow_id recurring intnotes)) {
                         delete $form->{$_};
                     }
                     my $wf = $form->{_wire}->get('workflows')
@@ -775,7 +775,7 @@ sub process_transactions {
                 #         $pt->{req}, "days" )
                 #       if $form->{reqdate};
 
-                #     for (qw(id recurring intnotes printed emailed)) {
+                #     for (qw(id recurring intnotes)) {
                 #         delete $form->{$_};
                 #     }
                 #     for ( 1 .. $form->{rowcount} ) {
