@@ -202,7 +202,7 @@ sub print_transaction {
     $form->{integer_amount} = $form->format_amount( \%myconfig, $whole );
 
     foreach my $field (qw(invtotal subtotal paid total)) {
-        $form->{$field} = $form->format_amount( \%myconfig, $form->{$field}, LedgerSMB::Setting->new(%$form)->get('decimal_places') );
+        $form->{$field} = $form->format_amount( \%myconfig, $form->{$field}, $form->get_setting('decimal_places') );
     }
 
     ( $form->{employee} ) = split /--/, $form->{employee};
@@ -233,16 +233,6 @@ sub print_transaction {
     } elsif ( $form->{media} !~ /(zip|screen)/ ) {
         $form->{OUT} = $form->{_wire}->get( 'printers' )->get( $form->{media} );
         $form->{printmode} = '|-';
-
-        if ( $form->{printed} !~ /$form->{formname}/ ) {
-
-            $form->{printed} .= " $form->{formname}";
-            $form->{printed} =~ s/^ //;
-
-            $form->update_status;
-        }
-
-        $old_form->{printed} = $form->{printed} if %$old_form;
     }
 
     $form->{fileid} = $form->{invnumber};
