@@ -812,37 +812,34 @@ sub form_footer {
     # type=submit $locale->text('Save as new')
     # type=submit $locale->text('Delete')
 
-    if ( !$form->{readonly} ) {
-
-        %button = (
-            'update' =>
-              { ndx => 1, key => 'U', value => $locale->text('Update') },
-            'save' => { ndx => 3, key => 'S', value => $locale->text('Save') },
+    %button = (
+        'update' =>
+        { ndx => 1, key => 'U', value => $locale->text('Update') },
+        'save' => { ndx => 3, key => 'S', value => $locale->text('Save') },
         );
 
-        if ( $form->{id} ) {
+    if ( $form->{id} ) {
 
-            if ( !$form->{isassemblyitem} ) {
-                $button{'save_as_new'} = {
-                    ndx   => 7,
-                    key   => 'N',
-                    value => $locale->text('Save as new')
-                };
-            }
-
-            if ( $form->{orphaned} ) {
-                $button{'delete'} =
-                  { ndx => 16, key => 'D', value => $locale->text('Delete') };
-            }
-        }
-        %button = () if $form->{isassemblyitem} && $form->{item} eq 'assembly';
-
-        for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button )
-        {
-            $form->print_button( \%button, $_ );
+        if ( !$form->{isassemblyitem} ) {
+            $button{'save_as_new'} = {
+                ndx   => 7,
+                key   => 'N',
+                value => $locale->text('Save as new')
+            };
         }
 
+        if ( $form->{orphaned} ) {
+            $button{'delete'} =
+            { ndx => 16, key => 'D', value => $locale->text('Delete') };
+        }
     }
+    %button = () if $form->{isassemblyitem} && $form->{item} eq 'assembly';
+
+    for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button )
+    {
+        $form->print_button( \%button, $_ );
+    }
+
     if ($form->{callback} and $form->{id}){
         print qq|<div class='returnlink'><a href='$form->{callback}'>|
               . $locale->text('Continue Previous Workflow')
@@ -1005,7 +1002,7 @@ sub vendor_row {
     </tr>
 |;
 
-    $form->{_setting_decimal_places} //= LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} //= $form->get_setting('decimal_places');
     foreach my $i ( 1 .. $numrows ) {
 
         if ( $form->{selectcurrency} ) {
@@ -1078,7 +1075,7 @@ sub customer_row {
 
     if ( $form->{selectpricegroup} ) {
         $pricegroup = qq|
-          <th class="listheading">| . $locale->text('Pricegroup') . qq|
+          <th class="listheading">| . $locale->text('Price group') . qq|
           </th>
 |;
     }
@@ -1105,7 +1102,7 @@ sub customer_row {
     </tr>
 |;
 
-    $form->{_setting_decimal_places} //= LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} //= $form->get_setting('decimal_places');
     foreach my $i ( 1 .. $numrows ) {
 
         if ( $form->{selectcurrency} ) {
@@ -1276,7 +1273,7 @@ sub assembly_row {
 
     $numrows-- if $form->{project_id};
 
-    $form->{_setting_decimal_places} //= LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} //= $form->get_setting('decimal_places');
     foreach my $i ( 1 .. $numrows ) {
         for (qw(partnumber description)) {
             $form->{"${_}_$i"} = $form->quote( $form->{"${_}_$i"} );
@@ -1474,8 +1471,9 @@ sub update {
                 $form->{rowcount} = $i;
                 $form->{assembly_rows}++;
 
-                &new_item;
-
+                $form->error(
+                    $locale->text('Part [_1] not on file!', $form->{"partnumber_$i"})
+                    );
             }
         }
 
