@@ -56,18 +56,18 @@ Deprecated
 
 package Form;
 
-use v5.36;
+use v5.36.1;
 use charnames qw(:full);
 use open ':utf8';
 use utf8;
-use Scalar::Util qw( blessed );
+
 
 use LedgerSMB;
 use LedgerSMB::Magic qw( SCRIPT_OLDSCRIPTS );
 use LedgerSMB::PGNumber;
 use LedgerSMB::Setting::Sequence;
 use LedgerSMB::Setting;
-
+use LedgerSMB::StopProcessing;
 
 use Carp;
 use List::Util qw(first);
@@ -368,8 +368,7 @@ This function replaces explicit 'exit()' calls.
 =cut
 
 sub finalize_request {
-    undef $@;
-    die;
+    LedgerSMB::StopProcessing->throw;
 }
 
 
@@ -735,8 +734,7 @@ Calls $form->error if the value is NaN.
 sub parse_amount {
     my ( $self, $myconfig, $amount ) = @_;
 
-    return $amount if (blessed $amount
-                       and $amount->isa( 'LedgerSMB::PGNumber' ));
+    return $amount if $amount isa 'LedgerSMB::PGNumber';
     if ( ( ! defined $amount ) or ( $amount eq '' ) ) {
         $amount = '0';
     }
@@ -758,8 +756,7 @@ is returned.
 sub parse_date {
     my ( $self, $myconfig, $date ) = @_;
 
-    return $date if (blessed $date
-                     and $date->isa( 'LedgerSMB::PGDate' ));
+    return $date if $date isa 'LedgerSMB::PGDate';
     if ( ( ! defined $date ) or ( $date eq '' ) ) {
         $date = '';
     }
@@ -1878,7 +1875,7 @@ If $form->{id} is set,
 populate the invnumber, transdate, ${vc}_id, datepaid, duedate, ordnumber,
 taxincluded, currency, notes, intnotes, ${vc}, department_id, department,
 oldinvtotal, employee_id, employee, language_code, ponumber,
-reverse, printed, emailed, recurring, exchangerate, and acc_trans
+reverse, recurring, exchangerate, and acc_trans
 attributes of $form with details about the transaction $form->{id}.  All of
 these attributes, save for acc_trans, are scalar; $form->{acc_trans} refers to
 a hash keyed by link elements whose values are lists of references to hashes
@@ -2028,24 +2025,6 @@ sub create_links {
 
         $sth->finish;
 
-        # get printed, emailed
-        $query = qq|
-            SELECT s.printed, s.emailed, s.formname
-            FROM status s WHERE s.trans_id = ?|;
-        $sth = $dbh->prepare($query);
-        $sth->execute( $self->{id} ) || $self->dberror($query);
-        while ( $ref = $sth->fetchrow_hashref('NAME_lc') ) {
-            $self->{printed} .= "$ref->{formname} "
-              if $ref->{printed};
-            $self->{emailed} .= "$ref->{formname} "
-              if $ref->{emailed};
-        }
-        $sth->finish;
-
-        for (qw(printed emailed)) {
-            $self->{$_} =~ s/ +$//g if $self->{$_}
-        }
-
     # get customer e-mail accounts
     $query = qq|SELECT * FROM eca__list_contacts(?)
                       WHERE class_id BETWEEN 12 AND ?
@@ -2431,120 +2410,6 @@ sub get_partsgroup {
     $sth->finish;
 }
 
-=item $form->update_status();
-
-DELETEs all status rows which have a formname of $form->{formname} and a
-trans_id of $form->{id}.  INSERTs a new row into status where trans_id is
-$form->{id}, formname is $form->{formname}, printed and emailed are true if
-their respective $form attributes match /$form->{formname}/.
-
-=cut
-
-sub update_status {
-
-    my ($self) = @_;
-
-    # no id return
-    return unless $self->{id};
-
-    my $dbh = $self->{dbh};
-
-    my $query = qq|DELETE FROM status
-                    WHERE formname = ?
-                      AND trans_id = ?|;
-
-    my $sth = $dbh->prepare($query);
-    $sth->execute(
-        $self->{formname},
-        $self->{id}
-    ) || $self->dberror($query);
-
-    $sth->finish;
-
-    return unless $self->{printed} || $self->{emailed};
-
-    my $printed = ( $self->{printed} =~ /$self->{formname}/ ) ? "1" : "0";
-    my $emailed = ( $self->{emailed} =~ /$self->{formname}/ ) ? "1" : "0";
-
-    $query = qq|
-        INSERT INTO status
-            (trans_id, printed, emailed, formname)
-        VALUES (?, ?, ?, ?)|;
-
-    $sth = $dbh->prepare($query);
-    $sth->execute(
-        $self->{id},
-        $printed,
-        $emailed,
-        $self->{formname}
-    ) || $self->dberror($query);
-
-    $sth->finish;
-}
-
-=item $form->save_status();
-
-Clears out any old status entries for $form->{id} and saves new status entries.
-Printed and emailed form
-names are extracted from $form->{printed} and $form->{emailed}.  The
-printed, and emailed fields are space separated lists.
-
-=cut
-
-sub save_status {
-
-    my ($self) = @_;
-    my $dbh = $self->{dbh};
-
-    my $formnames  = $self->{printed};
-    my $emailforms = $self->{emailed};
-
-    my $query = qq|DELETE FROM status
-                    WHERE trans_id = ?|;
-
-    my $sth = $dbh->prepare($query);
-    $sth->execute(
-        $self->{id}
-    ) || $self->dberror($query);
-    $sth->finish;
-
-    my $formname;
-    my $printed;
-    my $emailed;
-
-    # save printed, emailed info
-    $formnames  =~ s/^ +//g;
-    $emailforms =~ s/^ +//g;
-
-    my %status = ();
-    for (split / +/, $formnames) {
-        $status{$_}{printed} = 1
-    }
-
-    for (split / +/, $emailforms) {
-        $status{$_}{emailed} = 1
-    }
-
-    foreach my $formname ( keys %status ) {
-        $printed = ( $formnames  =~ /$self->{formname}/ ) ? "1" : "0";
-        $emailed = ( $emailforms =~ /$self->{formname}/ ) ? "1" : "0";
-
-        $query = qq|
-            INSERT INTO status (trans_id, printed, emailed,
-                formname)
-            VALUES (?, ?, ?, ?)|;
-
-        $sth = $dbh->prepare($query);
-        $sth->execute(
-            $self->{id},
-            $printed,
-            $emailed,
-            $formname
-        );
-        $sth->finish;
-    }
-}
-
 =item $form->get_recurring();
 
 Sets $form->{recurring} to contain info about the recurrence schedule for the
