@@ -42,7 +42,6 @@ package OE;
 
 use LedgerSMB::Magic qw(OEC_QUOTATION OEC_RFQ);
 use LedgerSMB::Num2text;
-use LedgerSMB::Setting;
 use LedgerSMB::Tax;
 
 use Log::Any;
@@ -501,9 +500,6 @@ VALUES (?, (select id from account where accno = ?), ?, ?, ?)
 
     $form->add_shipto($form->{id}, 1);
 
-    # save printed, emailed
-    $form->save_status($dbh);
-
     if ( $form->{type} =~ /_order$/ ) {
 
         # adjust onhand
@@ -545,12 +541,6 @@ sub delete {
     }
     $sth->finish;
 
-    # delete status entries
-    $query = qq|DELETE FROM status WHERE trans_id = ?|;
-    $sth   = $dbh->prepare($query);
-    $sth->execute( $form->{id} ) || $form->dberror($query);
-    $sth->finish;
-
     # delete individual entries
     $query = qq|DELETE FROM orderitems WHERE trans_id = ?|;
     $sth->finish;
@@ -585,8 +575,7 @@ sub retrieve {
     my $var;
     my $ref;
 
-    @{$form->{currencies}} =
-        (LedgerSMB::Setting->new(%$form))->get_currencies;
+    $form->{currencies} = $form->currencies;
     $form->{defaultcurrency} = $form->{currencies}->[0];
     $form->{lock_description} = $form->get_setting( 'lock_description' );
 
@@ -625,23 +614,6 @@ sub retrieve {
         for ( keys %$ref ) { $form->{$_} = $ref->{$_} }
         $sth->finish;
 
-        # get printed, emailed
-        $query = qq|
-            SELECT s.printed, s.emailed, s.formname
-            FROM status s
-            WHERE s.trans_id = ?|;
-        $sth = $dbh->prepare($query);
-        $sth->execute( $form->{id} ) || $form->dberror($query);
-
-        while ( $ref = $sth->fetchrow_hashref(NAME_lc) ) {
-            $form->{printed} .= "$ref->{formname} "
-              if $ref->{printed};
-            $form->{emailed} .= "$ref->{formname} "
-              if $ref->{emailed};
-        }
-        $sth->finish;
-        for (qw(printed emailed)) { $form->{$_} =~ s/ +$//g }
-
         # retrieve individual items
         $query = qq|
             SELECT o.id AS orderitems_id,
