@@ -1,21 +1,50 @@
 
 set client_min_messages = 'warning';
 
+/*
+
+
+  asset_report__generate_gl   - creates GL transaction upon approval of depreciation report
+  asset_report__disposal_gl   - creates GL transaction upon approval of a disposal (sale/abandonment)
+  asset_disposal__approve     - creates GL transaction upon approval of *partial* disposal (sale/abandonment)
+  asset__import_from_disposal - creates new assets from partially disposed assets, upon approval
+  asset_report__get_disposal  - returns a line per disposed asset in a disposal report with disposal details
+
+
+  call tree:
+
+    asset_report__approve
+      report_class of
+        '1': (depreciation)
+          asset_report__generate_gl
+        '2': (full disposal)
+          asset_report__disposal_gl
+            asset_report__get_disposal
+        '4': (partial disposal)
+          asset_disposal__approve
+            asset__import_from_disposal
+
+*/
+
 
 BEGIN;
 
+DROP FUNCTION IF EXISTS asset_dep__straight_line_base
+                        (numeric, numeric, numeric, numeric, numeric)
+     CASCADE;
+
 CREATE OR REPLACE FUNCTION asset_dep__straight_line_base
-(in_base_life numeric, in_life numeric, in_used numeric, in_basis numeric,
-in_dep_to_date numeric)
+(in_base_life numeric, in_used numeric, in_basis numeric, in_dep_to_date numeric)
 returns numeric as $$
-SELECT CASE WHEN $3/$1 * $4 < $4 - $5 THEN $3/$1 * $4
-            ELSE $4 - $5
+SELECT CASE WHEN in_used/in_base_life * in_basis < in_basis - in_dep_to_date
+                 THEN in_used/in_base_life * in_basis
+            ELSE in_basis - in_dep_to_date
             END;
 $$ language sql;
 
 COMMENT ON FUNCTION asset_dep__straight_line_base
-(in_base_life numeric, in_life numeric, in_used numeric, in_basis numeric,
-in_dep_to_date numeric) IS
+(in_base_life numeric, in_used numeric, in_basis numeric,
+ in_dep_to_date numeric) IS
 $$ This function is a basic function which does the actual calculation for
 straight line depreciation.$$;
 
@@ -23,10 +52,10 @@ CREATE OR REPLACE FUNCTION asset_dep__used_months
 (in_last_dep date, in_dep_date date, in_usable_life numeric)
 RETURNS numeric AS
 $$
-select CASE WHEN extract('MONTHS' FROM (date_trunc('day', $2) - date_trunc('day', $1)))
-                 > $3
-            THEN $3
-            ELSE extract('MONTHS' FROM (date_trunc('day', $2) - date_trunc('day', $1)))::numeric
+select CASE WHEN extract('MONTHS' FROM (date_trunc('day', in_dep_date) - date_trunc('day', in_last_dep)))
+                 > in_usable_life
+            THEN in_usable_life
+            ELSE extract('MONTHS' FROM (date_trunc('day', in_dep_date) - date_trunc('day', in_last_dep)))::numeric
             END;
 $$ language sql;
 
@@ -41,11 +70,12 @@ CREATE OR REPLACE FUNCTION asset_dep_get_usable_life_yr
 (in_usable_life numeric, in_start_date date, in_dep_date date)
 returns numeric as
 $$
-   SELECT CASE WHEN $3 IS NULL or get_fractional_year($2, $3) > $1
-               then $1
-               WHEN get_fractional_year($2, $3) < 0
+   SELECT CASE WHEN in_dep_date IS NULL
+                    or get_fractional_year(in_start_date, in_dep_date) > in_usable_life
+               then in_usable_life
+               WHEN get_fractional_year(in_start_date, in_dep_date) < 0
                THEN 0
-               ELSE get_fractional_year($2, $3)
+               ELSE get_fractional_year(in_start_date, in_dep_date)
           END;
 $$ language sql;
 
@@ -62,8 +92,8 @@ $$
 -- The addition of one day is so that it will return '1' when run on the end
 -- day of consecutive months.
 
-select (extract (months from age($2 + '1 day', $1 + '1 day'))
-       + extract (years from age($2, $1)) * 12)::int;
+select (extract (months from age(in_end + '1 day', in_start + '1 day'))
+       + extract (years from age(in_end, in_start)) * 12)::int;
 $$ language sql;
 
 COMMENT ON FUNCTION months_passed (in_start timestamp, in_end timestamp) IS
@@ -75,27 +105,23 @@ RETURNS bool AS
 $$
      INSERT INTO asset_report_line (asset_id, report_id, amount, department_id,
                                    warehouse_id)
-     SELECT ai.id, $3,
+     SELECT ai.id, in_report_id,
             asset_dep__straight_line_base(
                   ai.usable_life, -- years
-                  ai.usable_life -
                   get_fractional_year(coalesce(max(report_date),
                                                start_depreciation),
-                                      start_depreciation),
-                  get_fractional_year(coalesce(max(report_date),
-                                               start_depreciation),
-                                $2),
+                                      in_report_date),
                   purchase_value - salvage_value,
                   coalesce(sum(l.amount), 0)),
             ai.department_id, ai.location_id
        FROM asset_item ai
   LEFT JOIN asset_report_line l ON (l.asset_id = ai.id and l.amount > 0)
   LEFT JOIN asset_report r ON (l.report_id = r.id)
-      WHERE ai.id = ANY($1)
+      WHERE ai.id = ANY(in_asset_ids)
    GROUP BY ai.id, ai.start_depreciation, ai.purchase_date, ai.purchase_value,
             ai.salvage_value, ai.department_id, ai.location_id, ai.usable_life;
 
-    UPDATE asset_report SET report_class = 1 WHERE id = $3;
+    UPDATE asset_report SET report_class = 1 WHERE id = in_report_id;
 
     select true;
 $$ language sql;
@@ -108,27 +134,23 @@ RETURNS bool AS
 $$
      INSERT INTO asset_report_line (asset_id, report_id, amount, department_id,
                                    warehouse_id)
-     SELECT ai.id, $3,
+     SELECT ai.id, in_report_id,
             asset_dep__straight_line_base(
-                  ai.usable_life * 12,
-                  ai.usable_life * 12 --months
-                  - months_passed(start_depreciation,
-                                  coalesce(max(report_date),
-                                           start_depreciation)),
+                  ai.usable_life * 12, --months
                   months_passed(coalesce(max(report_date),
                                          start_depreciation),
-                                $2),
+                                in_report_date),
                   purchase_value - salvage_value,
                   coalesce(sum(l.amount), 0)),
             ai.department_id, ai.location_id
        FROM asset_item ai
   LEFT JOIN asset_report_line l ON (l.asset_id = ai.id and l.amount > 0)
   LEFT JOIN asset_report r ON (l.report_id = r.id)
-      WHERE ai.id = ANY($1)
+      WHERE ai.id = ANY(in_asset_ids)
    GROUP BY ai.id, ai.start_depreciation, ai.purchase_date, ai.purchase_value,
             ai.salvage_value, ai.department_id, ai.location_id, ai.usable_life;
 
-    UPDATE asset_report SET report_class = 1 WHERE id = $3;
+    UPDATE asset_report SET report_class = 1 WHERE id = in_report_id;
 
     select true;
 $$ language sql;
@@ -147,27 +169,23 @@ RETURNS bool AS
 $$
      INSERT INTO asset_report_line (asset_id, report_id, amount, department_id,
                                    warehouse_id)
-     SELECT ai.id, $3,
+     SELECT ai.id, in_report_id,
             asset_dep__straight_line_base(
-                  ai.usable_life,
-                  ai.usable_life --months
-                  - months_passed(start_depreciation,
-                                  coalesce(max(report_date),
-                                           start_depreciation)),
+                  ai.usable_life, --months
                   months_passed(coalesce(max(report_date),
                                          start_depreciation),
-                                $2),
+                                in_report_date),
                   purchase_value - salvage_value,
                   coalesce(sum(l.amount), 0)),
             ai.department_id, ai.location_id
        FROM asset_item ai
   LEFT JOIN asset_report_line l ON (l.asset_id = ai.id and l.amount > 0)
   LEFT JOIN asset_report r ON (l.report_id = r.id)
-      WHERE ai.id = ANY($1)
+      WHERE ai.id = ANY(in_asset_ids)
    GROUP BY ai.id, ai.start_depreciation, ai.purchase_date, ai.purchase_value,
             ai.salvage_value, ai.department_id, ai.location_id, ai.usable_life;
 
-    UPDATE asset_report SET report_class = 1 WHERE id = $3;
+    UPDATE asset_report SET report_class = 1 WHERE id = in_report_id;
 
     select true;
 $$ language sql;
@@ -271,24 +289,29 @@ CREATE OR REPLACE FUNCTION asset_class__search
 in_method int, in_label text)
 RETURNS SETOF asset_class_result AS
 $$
+BEGIN
+RETURN QUERY EXECUTE $sql$
                 SELECT ac.id, ac.asset_account_id, aa.accno, aa.description,
                         ac.dep_account_id, ad.accno, ad.description,
                         m.method, ac.method,
                         ac.label
                 FROM asset_class ac
-                JOIN account aa ON (aa.id = ac.asset_account_id)
-                JOIN account ad ON (ad.id = ac.dep_account_id)
+                LEFT JOIN account aa ON (aa.id = ac.asset_account_id)
+                LEFT JOIN account ad ON (ad.id = ac.dep_account_id)
                 JOIN asset_dep_method m ON (ac.method = m.id)
                 WHERE
-                        (in_asset_account_id is null
-                                or in_asset_account_id = ac.asset_account_id)
-                        AND (in_dep_account_id is null OR
-                                in_dep_account_id = ac.dep_account_id)
-                        AND (in_method is null OR in_method = ac.method)
-                        AND (in_label IS NULL OR ac.label LIKE
-                                '%' || in_label || '%')
+                        ($1 is null
+                                or $1 = ac.asset_account_id)
+                        AND ($2 is null OR
+                                $2 = ac.dep_account_id)
+                        AND ($3 is null OR $3 = ac.method)
+                        AND ($4 IS NULL OR ac.label LIKE
+                                '%' || $4 || '%')
                ORDER BY label
-$$ language sql;
+$sql$
+USING in_asset_account_id, in_dep_account_id, in_method, in_label;
+END
+$$ LANGUAGE PLPGSQL;
 
 COMMENT ON FUNCTION asset_class__search
 (in_asset_account_id int, in_dep_account_id int,
@@ -358,22 +381,29 @@ CREATE OR REPLACE FUNCTION asset__search
 (in_asset_class int, in_description text, in_tag text,
 in_purchase_date date, in_purchase_value numeric,
 in_usable_life numeric, in_salvage_value numeric)
-RETURNS SETOF asset_item AS $$
+RETURNS SETOF asset_item AS
+$$
+BEGIN
+RETURN QUERY EXECUTE $sql$
                 SELECT * FROM asset_item
-                WHERE (in_asset_class is null
-                        or asset_class_id = in_asset_class)
-                        AND (in_description is null or description
-                                LIKE '%' || in_description || '%')
-                        and (in_tag is null or tag like '%'||in_tag||'%')
-                        AND (in_purchase_date is null
-                                or purchase_date = in_purchase_date)
-                        AND (in_purchase_value is null
-                                or in_purchase_value = purchase_value)
-                        AND (in_usable_life is null
-                                or in_usable_life = usable_life)
-                        AND (in_salvage_value is null
-                                OR in_salvage_value = salvage_value);
-$$ LANGUAGE SQL;
+                WHERE ($1 is null
+                        or asset_class_id = $1)
+                        AND ($2 is null or description
+                                LIKE '%' || $2 || '%')
+                        and ($3 is null or tag like '%'||$3||'%')
+                        AND ($4 is null
+                                or purchase_date = $4)
+                        AND ($5 is null
+                                or $5 = purchase_value)
+                        AND ($6 is null
+                                or $6 = usable_life)
+                        AND ($7 is null
+                                OR $7 = salvage_value)
+$sql$
+USING in_asset_class, in_description, in_tag, in_purchase_date,
+ in_purchase_value, in_usable_life, in_salvage_value;
+END
+$$ LANGUAGE PLPGSQL;
 
 COMMENT ON FUNCTION asset__search
 (in_asset_class int, in_description text, in_tag text,
@@ -489,27 +519,35 @@ in_department_id int, in_invoice_id int,
 in_asset_account_id int, in_dep_account_id int)
 returns setof asset_item as
 $$
+BEGIN
+RETURN QUERY EXECUTE $sql$
          SELECT * FROM asset_item
-          WHERE (id = in_id or in_id is null)
-                and (asset_class_id = in_asset_class or in_asset_class is null)
-                and (description like '%'||in_description||'%'
-                     or in_description is null)
-                and (tag like '%' || in_tag || '%' or in_tag is null)
-                and (purchase_value = in_purchase_value
-                    or in_purchase_value is null)
-                and (in_purchase_date = purchase_date
-                    or in_purchase_date is null)
-                and (start_depreciation = in_start_depreciation
-                    or in_start_depreciation is null)
-                and (in_warehouse_id = location_id OR in_warehouse_id is null)
-                and (department_id = in_department_id
-                    or in_department_id is null)
-                and (in_invoice_id = invoice_id OR in_invoice_id IS NULL)
-                and (asset_account_id = in_asset_account_id
-                    or in_asset_account_id is null)
-                and (dep_account_id = in_dep_account_id
-                    or in_dep_account_id is null);
-$$ language sql;
+          WHERE (id = $1 or $1 is null)
+                and (asset_class_id = $2 or $2 is null)
+                and (description like '%'||$3||'%'
+                     or $3 is null)
+                and (tag like '%' || $4 || '%' or $4 is null)
+                and (purchase_value = $6
+                    or $6 is null)
+                and ($5 = purchase_date
+                    or $5 is null)
+                and (start_depreciation = $9
+                    or $9 is null)
+                and ($10 = location_id OR $10 is null)
+                and (department_id = $11
+                    or $11 is null)
+                and ($12 = invoice_id OR $12 IS NULL)
+                and (asset_account_id = $13
+                    or $13 is null)
+                and (dep_account_id = $14
+                    or $14 is null)
+$sql$
+USING in_id, in_asset_class, in_description, in_tag,
+in_purchase_date, in_purchase_value, in_usable_life, in_salvage_value,
+in_start_depreciation, in_warehouse_id, in_department_id, in_invoice_id,
+in_asset_account_id, in_dep_account_id;
+END
+$$ LANGUAGE PLPGSQL;
 
 COMMENT ON FUNCTION asset_item__search
 (in_id int, in_asset_class int, in_description text, in_tag text,
@@ -524,7 +562,7 @@ Tag and description allow for partial match.  All other matches are exact.$$;
 CREATE OR REPLACE FUNCTION asset_class__get_dep_method (in_asset_class int)
 RETURNS asset_dep_method AS $$
 SELECT * from asset_dep_method
-WHERE id = (select method from asset_class where id = $1);
+WHERE id = (select method from asset_class where id = in_asset_class);
 $$ language sql;
 
 COMMENT ON FUNCTION asset_class__get_dep_method (in_asset_class int) IS
@@ -598,17 +636,17 @@ $$ Disposes of an asset.  in_dm is the disposal method id.$$;
 DROP TYPE IF EXISTS asset_disposal_report_line CASCADE;
 CREATE TYPE asset_disposal_report_line
 AS (
-       id int,
-       tag text,
-       description text,
-       start_dep date,
-       disposed_on date,
-       dm char(1),
-       purchase_value numeric,
-       accum_depreciation numeric,
-       disposal_amt numeric,
-       adj_basis numeric,
-       gain_loss numeric
+  id int,
+  tag text,
+  description text,
+  start_dep date,
+  disposed_on date,
+  dm char(1),
+  purchase_value numeric,
+  accum_depreciation numeric,
+  disposal_amt numeric,
+  adj_basis numeric,
+  gain_loss numeric
 );
 
 CREATE OR REPLACE FUNCTION asset_report__get_disposal (in_id int)
@@ -628,13 +666,13 @@ $$
                                                   ELSE 0
                                               END) as gain_loss
      FROM asset_item ai
-     JOIN asset_report_line l   ON (l.report_id = $1 AND ai.id = l.asset_id)
+     JOIN asset_report_line l   ON (l.report_id = in_id AND ai.id = l.asset_id)
      JOIN asset_report r        ON (l.report_id = r.id)
 LEFT JOIN asset_rl_to_disposal_method adm
                              USING (report_id, asset_id)
      JOIN asset_disposal_method dm
                                 ON (adm.disposal_method_id = dm.id)
-LEFT JOIN asset_report_line prl ON (prl.report_id <> $1
+LEFT JOIN asset_report_line prl ON (prl.report_id <> in_id
                                    AND ai.id = prl.asset_id)
 LEFT JOIN asset_report pr       ON (prl.report_id = pr.id)
  GROUP BY ai.id, ai.tag, ai.description, ai.start_depreciation, r.report_date,
@@ -666,11 +704,13 @@ CREATE TYPE asset_nbv_line AS (
 CREATE OR REPLACE FUNCTION asset_nbv_report ()
 returns setof asset_nbv_line AS
 $$
+BEGIN
+RETURN QUERY EXECUTE $sql$
    SELECT ai.id, ai.tag, ai.description, ai.start_depreciation,
           adm.short_name, ai.usable_life
            - months_passed(ai.start_depreciation,
                                   coalesce(max(r.report_date),
-                                    ai.start_depreciation))/ 12,
+                                    ai.start_depreciation))/(case when adm.unit_label='in years' then 12 else 1 end),
           ai.purchase_value - ai.salvage_value, ai.salvage_value, max(r.report_date),
           sum(rl.amount), ai.purchase_value - coalesce(sum(rl.amount), 0)
      FROM asset_item ai
@@ -683,34 +723,36 @@ LEFT JOIN (select arl.*
 LEFT JOIN asset_report r on (rl.report_id = r.id)
     WHERE r.id IS NULL OR r.approved_at IS NOT NULL
  GROUP BY ai.id, ai.tag, ai.description, ai.start_depreciation, ai.purchase_date,
-          adm.short_name, ai.usable_life, ai.purchase_value, salvage_value
-   HAVING (NOT 2 = ANY(as_array(r.report_class)))
-          AND (NOT 4 = ANY(as_array(r.report_class)))
+          adm.short_name, adm.unit_label, ai.usable_life, ai.purchase_value, salvage_value
+   HAVING (NOT 2 = ANY(array_agg(r.report_class)))
+          AND (NOT 4 = ANY(array_agg(r.report_class)))
           OR max(r.report_class) IS NULL
- ORDER BY ai.id, ai.tag, ai.description;
-$$ language sql;
+ ORDER BY ai.id, ai.tag, ai.description
+$sql$;
+END
+$$ LANGUAGE PLPGSQL;
 
 COMMENT ON FUNCTION asset_nbv_report () IS
 $$ Returns the current net book value report.$$;
 
 DROP TYPE IF EXISTS partial_disposal_line CASCADE;
 CREATE TYPE partial_disposal_line AS (
-id int,
-tag text,
-begin_depreciation date,
-purchase_value numeric,
-description text,
-disposal_date date,
-percent_disposed numeric,
-disposed_acquired_value numeric,
-percent_remaining numeric,
-remaining_aquired_value numeric
+  id int,
+  tag text,
+  description text,
+  start_dep date,
+  purchase_value numeric,
+  disposal_date date,
+  percent_disposed numeric,
+  disposed_acquired_value numeric,
+  percent_remaining numeric,
+  remaining_aquired_value numeric
 );
 
 CREATE OR REPLACE FUNCTION asset_report_partial_disposal_details(in_id int)
 RETURNS SETOF PARTIAL_DISPOSAL_LINE AS
 $$
-SELECT ai.id, ai.tag, ai.start_depreciation, ai.purchase_value, ai.description,
+SELECT ai.id, ai.tag, ai.description, ai.start_depreciation, ai.purchase_value,
        ar.report_date, arld.percent_disposed,
        (arld.percent_disposed / 100) * ai.purchase_value,
        100 - arld.percent_disposed,
@@ -720,14 +762,16 @@ SELECT ai.id, ai.tag, ai.start_depreciation, ai.purchase_value, ai.description,
   JOIN asset_report ar ON (ar.id = l.report_id)
   JOIN asset_rl_to_disposal_method arld
        ON  ((arld.report_id, arld.asset_id) = (l.report_id, l.asset_id))
- WHERE ar.id = $1;
+ WHERE ar.id = in_id;
 $$ LANGUAGE SQL;
 
 COMMENT ON FUNCTION asset_report_partial_disposal_details(in_id int) IS
 $$ Returns the partial disposal details for a partial disposal report.$$;
 
+DROP FUNCTION IF EXISTS asset_report__approve(int, int, int, int);
+
 CREATE OR REPLACE FUNCTION asset_report__approve
-(in_id int, in_expense_acct int, in_gain_acct int, in_loss_acct int)
+(in_id int, in_expense_acct int, in_gain_acct int, in_loss_acct int, in_cash_acct int)
 RETURNS asset_report AS
 $$
 DECLARE ret_val asset_report;
@@ -742,7 +786,7 @@ BEGIN
                     PERFORM asset_report__generate_gl(in_id, in_expense_acct);
                 ELSIF ret_val.report_class = 2 THEN
                     PERFORM asset_report__disposal_gl(
-                                 in_id, in_gain_acct, in_loss_acct);
+                                 in_id, in_gain_acct, in_loss_acct, in_cash_acct);
                 ELSIF ret_val.report_class = 4 THEN
                     PERFORM asset_disposal__approve(in_id, in_gain_acct, in_loss_acct, (select asset_account_id from asset_class
                                                                                          where id = ret_val.asset_class)
@@ -754,71 +798,87 @@ BEGIN
         RETURN ret_val;
 end;
 $$ language plpgsql;
-revoke execute on function asset_report__approve(int, int, int, int) from public;
+revoke execute on function asset_report__approve(int, int, int, int, int) from public;
 
-COMMENT ON function asset_report__approve(int, int, int, int) is
+COMMENT ON function asset_report__approve(int, int, int, int, int) is
 $$ This function approves an asset report (whether depreciation or disposal).
 Also generates relevant GL drafts for review and posting.$$;
 
+DROP FUNCTION IF EXISTS asset_report__disposal_gl(int, int, int);
+
 CREATE OR REPLACE FUNCTION asset_report__disposal_gl
-(in_id int, in_gain_acct int, in_loss_acct int)
+(in_id int, in_gain_acct int, in_loss_acct int, in_cash_acct int)
 RETURNS bool AS
 $$
   INSERT INTO gl (reference, description, transdate, approved, trans_type_code)
   SELECT setting_increment('glnumber'), 'Asset Report ' || asset_report.id,
                 report_date, false, 'fd'
     FROM asset_report
-    JOIN asset_report_line ON (asset_report.id = asset_report_line.report_id)
-    JOIN asset_item        ON (asset_report_line.asset_id = asset_item.id)
-   WHERE asset_report.id = $1
-GROUP BY asset_report.id, asset_report.report_date;
+  WHERE asset_report.id = in_id;
 
+  -- Clear cumulative depreciation account
   INSERT
     INTO acc_trans (chart_id, trans_id, amount_bc, curr, amount_tc,
                     approved, transdate)
   SELECT a.dep_account_id, currval('id')::int, sum(r.accum_depreciation) * -1,
          defaults_get_defaultcurrency(), sum(r.accum_depreciation) * -1,
          TRUE, r.disposed_on
-    FROM asset_report__get_disposal($1) r
+    FROM asset_report__get_disposal(in_id) r
     JOIN asset_item a ON (r.id = a.id)
-GROUP BY a.dep_account_id, r.disposed_on;
+   GROUP BY a.dep_account_id, r.disposed_on
+  HAVING sum(r.accum_depreciation) <> 0;
+
+  -- Add cash from sale(=disposal)
+  INSERT
+    INTO acc_trans (chart_id, trans_id, amount_bc, curr, amount_tc,
+                    approved, transdate)
+  SELECT in_cash_acct, currval('id')::int, sum(r.disposal_amt) * -1,
+         defaults_get_defaultcurrency(), sum(r.disposal_amt) * -1,
+         TRUE, r.disposed_on
+    FROM asset_report__get_disposal(in_id) r
+    JOIN asset_item ai ON (r.id = ai.id)
+   GROUP BY r.disposed_on
+  HAVING sum(r.disposal_amt) <> 0;
 
   -- GAIN is negative since it is a debit
   INSERT
     INTO acc_trans (chart_id, trans_id, amount_bc, curr, amount_tc,
                     approved, transdate)
-  SELECT case when sum(r.gain_loss) > 0 THEN $3 else $2 end,
+  SELECT case when sum(r.gain_loss) > 0 THEN in_loss_acct else in_gain_acct end,
          currval('id')::int, sum(r.gain_loss), defaults_get_defaultcurrency(),
          sum(r.gain_loss),
          TRUE, r.disposed_on
-    FROM asset_report__get_disposal($1) r
+    FROM asset_report__get_disposal(in_id) r
     JOIN asset_item ai ON (r.id = ai.id)
-GROUP BY r.disposed_on;
+   GROUP BY r.disposed_on;
 
+  -- Clear asset from asset account
   INSERT
     INTO acc_trans (chart_id, trans_id, amount_bc, curr, amount_tc,
                     approved, transdate)
   SELECT a.asset_account_id, currval('id')::int, sum(r.purchase_value),
          defaults_get_defaultcurrency(), sum(r.purchase_value),
          TRUE, r.disposed_on
-    FROM asset_report__get_disposal($1) r
+    FROM asset_report__get_disposal(in_id) r
     JOIN asset_item a ON (r.id = a.id)
-GROUP BY a.asset_account_id, r.disposed_on;
+   GROUP BY a.asset_account_id, r.disposed_on
+  HAVING sum(r.purchase_value) <> 0;
 
 
   SELECT TRUE;
 $$ language sql;
 
 COMMENT ON  FUNCTION asset_report__disposal_gl
-(in_id int, in_gain_acct int, in_loss_acct int) IS
+(in_id int, in_gain_acct int, in_loss_acct int, in_cash_acct int) IS
 $$ Generates GL transactions for ful disposal reports.$$;
 
 
 CREATE OR REPLACE FUNCTION asset_item__add_note(in_id int, in_subject text, in_note text)
 RETURNS asset_note AS
 $$
-INSERT INTO asset_note (ref_key, subject, note) values ($1, $2, $3);
-SELECT * FROM asset_note WHERE id = currval('note_id_seq');
+INSERT INTO asset_note (ref_key, subject, note)
+  values (in_id, in_subject, in_note)
+RETURNING *;
 $$ language sql;
 
 COMMENT ON FUNCTION asset_item__add_note(in_id int, in_subject text,
@@ -849,6 +909,12 @@ AS $$
     SELECT * FROM account__get_by_link_desc('asset_loss');
 $$ language sql;
 
+CREATE OR REPLACE FUNCTION asset_report__get_cash_accts()
+RETURNS SETOF account
+AS $$
+  SELECT * FROM account where not obsolete;
+$$ language sql;
+
 COMMENT ON FUNCTION asset_report__get_loss_accts() IS
 $$ Returns a list of loss accounts for asset depreciation and disposal reports.
 $$;
@@ -857,7 +923,7 @@ CREATE OR REPLACE FUNCTION asset_report__get(in_id int)
 RETURNS asset_report
 AS
 $$
-select * from asset_report where id = $1;
+select * from asset_report where id = in_id;
 $$ language sql;
 
 COMMENT ON FUNCTION asset_report__get(in_id int) IS
@@ -905,7 +971,7 @@ as $$
      JOIN asset_report r ON (rl.report_id = r.id)
 LEFT JOIN asset_report_line prl ON (prl.asset_id = ai.id)
 LEFT JOIN asset_report pr ON (prl.report_id = pr.id)
-    WHERE rl.report_id = $1
+    WHERE rl.report_id = in_id
  GROUP BY ai.tag, ai.start_depreciation, ai.purchase_value, m.short_name,
           ai.usable_life, ai.salvage_value, r.report_date, rl.amount,
           ai.description, ai.purchase_date;
@@ -941,13 +1007,13 @@ returns setof asset_report_result AS $$
          r.depreciated_qty, r.dont_approve, r.submitted, sum(l.amount)
     FROM asset_report r
     JOIN asset_report_line l ON (l.report_id = r.id)
-   where ($1 is null or $1 <= report_date)
-         and ($2 is null or $2 >= report_date)
-         and ($3 is null or $3 = asset_class)
-         and ($4 is null
-              or ($4 is true and approved_by is not null)
-              or ($4 is false and approved_by is null))
-         and ($5 is null or $5 = entered_by)
+   where (in_start_date is null or in_start_date <= report_date)
+         and (in_end_date is null or in_end_date >= report_date)
+         and (in_asset_class is null or in_asset_class = asset_class)
+         and (in_approved is null
+              or (in_approved is true and approved_by is not null)
+              or (in_approved is false and approved_by is null))
+         and (in_entered_by is null or in_entered_by = entered_by)
 GROUP BY r.id, r.report_date, r.gl_id, r.asset_class, r.report_class,
          r.entered_by, r.approved_by, r.entered_at, r.approved_at,
          r.depreciated_qty, r.dont_approve, r.submitted;
@@ -969,18 +1035,18 @@ $$
      JOIN asset_class ac ON (ai.asset_class_id = ac.id)
 LEFT JOIN asset_report_line arl ON (arl.asset_id = ai.id)
 LEFT JOIN asset_report ar ON (arl.report_id = ar.id)
-    WHERE ai.start_depreciation <= $3 AND ac.id = $2
+    WHERE ai.start_depreciation <= in_report_date AND ac.id = in_asset_class
           AND obsolete_by IS NULL
  GROUP BY ai.id, ai.tag, ai.description, ai.purchase_value, ai.usable_life,
           ai.purchase_date, ai.location_id, ai.invoice_id, ai.asset_account_id,
           ai.dep_account_id, ai.asset_class_id, ai.start_depreciation,
           ai.salvage_value, ai.department_id, ai.exp_account_id, ai.obsolete_by
    HAVING (count(ar.report_class) = 0 OR
-          (2 <> ALL(as_array(ar.report_class))
-          and 4 <> ALL(as_array(ar.report_class))))
+          (2 <> ALL(array_agg(ar.report_class))
+          and 4 <> ALL(array_agg(ar.report_class))))
           AND ((ai.purchase_value - coalesce(sum(arl.amount), 0)
                > ai.salvage_value) and ai.obsolete_by is null)
-               OR $1 is not true;
+               OR in_depreciation is not true;
 $$ language sql;
 
 COMMENT ON FUNCTION asset_report__generate
@@ -994,7 +1060,7 @@ returns asset_report as
 $$
 INSERT INTO asset_report (asset_class, report_date, entered_at, entered_by,
             report_class, dont_approve)
-     VALUES ($1, $2, now(), person__get_my_entity_id(),
+     VALUES (in_asset_class, in_report_date, now(), person__get_my_entity_id(),
             3, true);
 
 SELECT * FROM asset_report where id = currval('asset_report_id_seq');
@@ -1006,23 +1072,23 @@ COMMENT ON FUNCTION asset_report__begin_import
 $$Creates the outline of an asset import report$$;
 
 CREATE OR REPLACE FUNCTION asset_report__import(
-        in_description text,       -- $1
-        in_tag text,               -- $2
-        in_purchase_value numeric, -- $3
-        in_salvage_value numeric,  -- $4
-        in_usable_life numeric,    -- $5
-        in_purchase_date date,     -- $6
-        in_start_depreciation date,-- $7
-        in_location_id int,        -- $8
-        in_department_id int,      -- $9
-        in_asset_account_id int,   -- $10
-        in_dep_account_id int,     -- $11
-        in_exp_account_id int,     -- $12
-        in_asset_class_id int,     -- $13
-        in_invoice_id int,         -- $14
-        in_dep_report_id int,      -- $15
-        in_accum_dep numeric,      -- $16
-        in_obsolete_other bool     -- $17
+        in_description text,
+        in_tag text,
+        in_purchase_value numeric,
+        in_salvage_value numeric,
+        in_usable_life numeric,
+        in_purchase_date date,
+        in_start_depreciation date,
+        in_location_id int,
+        in_department_id int,
+        in_asset_account_id int,
+        in_dep_account_id int,
+        in_exp_account_id int,
+        in_asset_class_id int,
+        in_invoice_id int,
+        in_dep_report_id int,
+        in_accum_dep numeric,
+        in_obsolete_other bool
 )
 RETURNS bool AS
 $$
@@ -1030,21 +1096,21 @@ $$
 INSERT
   INTO asset_report_line
        (report_id, asset_id, amount, department_id, warehouse_id)
-select $15, id, $16, department_id, location_id
+select in_dep_report_id, id, in_accum_dep, department_id, location_id
   from asset__save
-       (NULL, $13, $1, $2, $6, $3, $5, coalesce($4, 0), $7, $8, $9, $14, $10,
-        $11, $12, (select min(id) from asset_item where tag = $2));
+       (NULL, in_asset_class_id, in_description, in_tag, in_purchase_date, in_purchase_value, in_usable_life, coalesce(in_salvage_value, 0), in_start_depreciation, in_location_id, in_department_id, in_invoice_id, in_asset_account_id,
+        in_dep_account_id, in_exp_account_id, (select min(id) from asset_item where tag = in_tag));
       -- use 'min(id)' because the first record in the series will be deprecated
       -- by by another one; chances are nil that it's actually deprecat*ing* one
 
 UPDATE asset_item
    SET obsolete_by = currval('asset_item_id_seq')
- WHERE tag = $2 and $17 is true
-       and id = (select min(id) from asset_item where tag = $2);
+ WHERE tag = in_tag and in_obsolete_other is true
+       and id = (select min(id) from asset_item where tag = in_tag);
 
 UPDATE asset_item
    SET obsolete_by = NULL
- WHERE tag = $2 and $17 is true
+ WHERE tag = in_tag and in_obsolete_other is true
        and id = currval('asset_item_id_seq');
 
 SELECT true;
@@ -1096,7 +1162,7 @@ $$ language plpgsql;
 
 COMMENT ON FUNCTION asset_report__begin_disposal
 (in_asset_class int, in_report_date date, in_report_class int) IS
-$$ Creates the asset report recofd for the asset disposal report.$$;
+$$ Creates the asset report record for the asset disposal report.$$;
 
 create or replace function asset_report__record_approve(in_id int)
 returns asset_report
@@ -1104,9 +1170,9 @@ as $$
 UPDATE asset_report
    set approved_by = person__get_my_entity_id(),
        approved_at = now()
- where id = $1;
+ where id = in_id;
 
-select * from asset_report where id = $1;
+select * from asset_report where id = in_id;
 
 $$ language sql;
 
@@ -1250,8 +1316,8 @@ BEGIN
     PERFORM asset_report__import(
         ai.description,
         ai.tag,
-        ai.purchase_value * rld.percent_disposed / 100,
-        ai.salvage_value * rld.percent_disposed / 100,
+        ai.purchase_value * ( 100 - rld.percent_disposed ) / 100,
+        ai.salvage_value * ( 100 - rld.percent_disposed ) / 100,
         ai.usable_life,
         ai.purchase_date,
         ai.start_depreciation,
@@ -1263,7 +1329,7 @@ BEGIN
         ai.asset_class_id,
         ai.invoice_id,
         t_import.id,
-        r.accum_depreciation * rld.percent_disposed / 100,
+        r.accum_depreciation * ( 100 - rld.percent_disposed ) / 100,
         TRUE)
     FROM asset_item ai
     JOIN asset_report__get_disposal(t_report.id) r  ON (ai.id = r.id)
