@@ -44,7 +44,7 @@ BEGIN
 RETURN QUERY EXECUTE $sql$
               SELECT ec.id, coalesce(ec.pay_to_name, e.name ||
                      coalesce(':' || ec.description,'')) as name,
-                     e.entity_class, ec.discount_account_id, ec.meta_number
+                     ec.entity_class, ec.discount_account_id, ec.meta_number
                 FROM entity_credit_account ec
                 JOIN entity e ON (ec.entity_id = e.id)
                 WHERE ec.entity_class = $1
@@ -84,7 +84,7 @@ DECLARE
 BEGIN
 EXECUTE $sql$
  SELECT ec.id, coalesce(ec.pay_to_name, cp.name  || coalesce(':' || ec.description, ''), '') as name,
-        e.entity_class, ec.discount_account_id, ec.meta_number
+        ec.entity_class, ec.discount_account_id, ec.meta_number
  FROM entity_credit_account ec
  JOIN entity e ON (ec.entity_id = e.id)
  JOIN (
@@ -165,8 +165,10 @@ END
 $$ LANGUAGE PLPGSQL;
 
 COMMENT ON FUNCTION payment_get_open_accounts(int, date, date) IS
-$$ This function takes a single argument (1 for vendor, 2 for customer as
-always) and returns all entities with open accounts of the appropriate type. $$;
+  $$ This function takes an argument (1 for vendor, 2 for customer)
+  and 'from' and 'to' dates and returns all entities with open accounts of the appropriate type
+  which have a validity interval (between 'start' and 'end' dates) which overlaps with the
+  interval between 'from' and 'to' dates. $$;
 
 DROP FUNCTION if exists payment_get_all_accounts(int);
 
@@ -179,7 +181,7 @@ RETURN QUERY EXECUTE $sql$
                         e.name, ec.entity_class
                 FROM entity e
                 JOIN entity_credit_account ec ON (ec.entity_id = e.id)
-                                WHERE e.entity_class = $1
+                                WHERE ec.entity_class = $1
 $sql$
 USING in_account_class;
 END
@@ -1528,10 +1530,11 @@ CREATE OR REPLACE FUNCTION payment_get_open_overpayment_entities(in_account_clas
 $$
 BEGIN
 RETURN QUERY EXECUTE $sql$
-                SELECT DISTINCT entity_credit_id, legal_name, e.entity_class, null::int, o.meta_number
-                FROM overpayments o
-                JOIN entity e ON (e.id=o.entity_id)
-                WHERE available <> 0 AND $1 = payment_class
+  SELECT DISTINCT entity_credit_id, legal_name, ec.entity_class, null::int, o.meta_number
+    FROM overpayments o
+    JOIN entity e ON e.id = o.entity_id
+    JOIN entity_credit_account ec ON o.entity_credit_id = ec.id
+   WHERE available <> 0 AND $1 = payment_class
 $sql$
 USING in_account_class;
 END
