@@ -28,12 +28,25 @@ msgstr ""
 EOF
 
 # EXTRACT STRINGS AND CREATE POT
-find . -name '*.pl' -o -name '*.pm' | \
-  grep -v '\(b\|xt/\)lib/\|UI/pod/\|\./\.[a-z]*\+' | grep -v LaTeX | sort | \
+find . \
+     \( -path ./devel \
+        -o -path ./xt/lib \
+        -o -path ./xt/66-cucumber \
+        -o -path ./sql \
+        -o -path ./b \
+        -o -path ./UI/pod \
+        -o -path ./UI/node_modules \
+        -o -path ./utils/devel \
+        -o -path './.*' \) -prune \
+     -o \(  -name '*.pl' -o -name '*.pm' \) -not -name '*LaTeX*' -print | \
+  sort | \
   utils/devel/extract-perl >> locale/LedgerSMB.pot
 
 find UI/ templates/ t/data/ \
-     -name '*.html' -o -name '*.tex' -o -name '*.csv' | \
+     -path UI/node_modules -prune \
+     -o -name '*.html' \
+     -o -name '*.tex' \
+     -o -name '*.csv' | \
    grep -v 'UI/\(js\|pod\)/' | sort | \
    utils/devel/extract-template-translations >> locale/LedgerSMB.pot
 
@@ -41,6 +54,8 @@ utils/devel/extract-sql < sql/Pg-database.sql >> locale/LedgerSMB.pot
 
 utils/devel/extract-vue-template-translations.sh >> locale/LedgerSMB.pot
 
+utils/devel/extract-menu-translations >> locale/LedgerSMB.pot
+
 msguniq --sort-output --width=80 --output-file=locale/LedgerSMB.pot locale/LedgerSMB.pot \
   || exit 1
 
