@@ -107,14 +107,18 @@ my %screens = (
     'Create New Batch' => 'PageObject::App::Cash::Vouchers::Payments',
     'Edit Contact' => 'PageObject::App::Contacts::EditContact',
     'Edit currencies' => 'PageObject::App::System::Currency::EditCurrencies',
+    'Edit Employee' => 'PageObject::App::Contacts::EditEmployee',
     'Edit rate types' => 'PageObject::App::System::Currency::EditRateTypes',
     'Edit rates' => 'PageObject::App::System::Currency::EditRates',
-    'Employee search' => 'PageObject::App::Search::Contact',
+    'Employee Search Report' => 'PageObject::App::Search::ReportDynatable',
+    'Employee Search' => 'PageObject::App::Search::Employee',
     'Enter Inventory' => ' PageObject::App::Parts::AdjustSetup',
     'Filtering Payments' => 'PageObject::App::Cash::Vouchers::Payments::Filter',
     'GL entry'  => 'PageObject::App::GL::JournalEntry',
     'GL search' => 'PageObject::App::Search::GL',
+    'GL report' => 'PageObject::App::Search::ReportDynatable',
     'New Reconciliation Report' => 'PageObject::App::Cash::Reconciliation::NewReport',
+    'Search AP Report' => 'PageObject::App::Search::ReportDynatable',
     'Single Payment Vendor Selection' => 'PageObject::App::Cash::SelectVC',
     'Single Payment Customer Selection' => 'PageObject::App::Cash::SelectVC',
     'Single Payment Entry' => 'PageObject::App::Cash::Entry',
@@ -186,7 +190,7 @@ When qr/I open the parts screen for '(.*)'/, sub {
     my $partnumber = $1;
 
     S->{ext_wsl}->page->body->menu->click_menu(
-        ['Goods and Services', 'Search']
+        ['Goods & Services', 'Search']
     );
     S->{ext_wsl}->page->body->maindiv->content->search(
         'Part Number' => $partnumber
